@@ -6,9 +6,12 @@ bdgraph.mpl = function( data, n = NULL, method = "ggm", transfer = TRUE, algorit
 					g.space = NULL, g.prior = 0.5, multi.update = NULL, alpha = 0.5, 
 					save.all = FALSE, print = 1000, cores = "all", operator = "or" )
 {
+	check.os( os = 2 )	
 	if( cores == "all" ) cores = detect_cores()
 	.C( "omp_set_num_cores", as.integer( cores ), PACKAGE = "BDgraph" )
-
+	tmp <- .C( "check_nthread", cores = as.integer(cores), PACKAGE = "BDgraph" )
+	cores = tmp $ cores
+	
 	burnin = floor( burnin )
 	
 	if( class( data ) == "sim" ) data <- data $ data
